@@ -45,16 +45,13 @@ Here is the default configuration for the `bazel` element
      :language: yaml
 """
 
-from buildstream import BuildElement, SandboxFlags
+from buildstream import BuildElement
 
 
 class BazelElement(BuildElement):
 
     BST_MIN_VERSION = "2.0"
 
-    # Supports virtual directories (required for remote execution)
-    BST_VIRTUAL_DIRECTORY = True
-
     def configure_sandbox(self, sandbox):
         super().configure_sandbox(sandbox)
 
@@ -65,12 +62,6 @@ class BazelElement(BuildElement):
         #
         sandbox.mark_directory("/bazel-home")
 
-        # Enable command batching across prepare() and assemble()
-        self.batch_prepare_assemble(
-            SandboxFlags.ROOT_READ_ONLY,
-            collect=self.get_variable("install-root"),
-        )
-
 
 def setup():
     return BazelElement
