@@ -120,7 +120,6 @@ from buildstream import BuildElement, ElementError, Node
 # Element implementation for the 'dpkg' kind.
 class DpkgElement(BuildElement):
     BST_MIN_VERSION = "2.0"
-    BST_VIRTUAL_DIRECTORY = True
 
     def _get_packages(self, sandbox):
         vdir = sandbox.get_virtual_directory()
@@ -130,7 +129,7 @@ class DpkgElement(BuildElement):
             self.get_variable("build-root").lstrip(os.sep),
             controlfile,
         )
-        with vdir.open_file(*controlpath.split(os.sep)) as f:
+        with vdir.open_file(controlpath) as f:
             return re.findall(r"Package:\s*(.+)\n", f.read())
 
     def configure(self, node):
@@ -161,8 +160,10 @@ class DpkgElement(BuildElement):
         collectdir = super().assemble(sandbox)
 
         vdir = sandbox.get_virtual_directory()
-        debian_dir = vdir.descend(
-            *self.get_variable("build-root").split(os.sep), "debian"
+        debian_dir = vdir.open_directory(
+            os.path.join(self.get_variable("build-root"), "debian").lstrip(
+                os.sep
+            )
         )
 
         bad_overlaps = set()
@@ -172,7 +173,7 @@ class DpkgElement(BuildElement):
         have_package_scripts = False
         for package in packages:
 
-            package_dir = debian_dir.descend(package)
+            package_dir = debian_dir.open_directory(package)
 
             # Exclude DEBIAN files because they're pulled in as public metadata
             contents = [
@@ -190,32 +191,34 @@ class DpkgElement(BuildElement):
             for content_file in contents:
                 for split_package, split_contents in new_split_rules.items():
                     for split_file in split_contents.as_str_list():
-                        split_package_dir = debian_dir.descend(split_package)
+                        split_package_dir = debian_dir.open_directory(
+                            split_package
+                        )
                         if (
                             content_file == split_file
-                            and package_dir.isfile(*content_file.split(os.sep))
+                            and package_dir.isfile(content_file.lstrip(os.sep))
                             and split_package_dir.isfile(
-                                *split_file.split(os.sep)
+                                split_file.lstrip(os.sep)
                             )
                         ):
                             content_file_digest = package_dir.file_digest(
-                                *content_file.split(os.sep)
+                                content_file.lstrip(os.sep)
                             )
                             split_file_digest = package_dir.file_digest(
-                                *split_file.split(os.sep)
+                                split_file.lstrip(os.sep)
                             )
                             if content_file_digest != split_file_digest:
                                 bad_overlaps.add(content_file)
 
             # Store /DEBIAN metadata for each package.
             # DEBIAN/control goes into bst.dpkg-data.<package>.control
-            if not package_dir.exists("DEBIAN", "control"):
+            if not package_dir.exists("DEBIAN/control"):
                 raise ElementError(
                     "{}: package {} doesn't have a DEBIAN/control in {}!".format(
                         self.name, package, str(package_dir)
                     )
                 )
-            with package_dir.open_file("DEBIAN", "control", mode="r") as f:
+            with package_dir.open_file("DEBIAN/control", mode="r") as f:
                 controldata = f.read()
 
             # Setup the package data
@@ -225,11 +228,13 @@ class DpkgElement(BuildElement):
             package_scripts = Node.from_dict({})
             scriptfiles = ["preinst", "postinst", "prerm", "postrm"]
             for s in scriptfiles:
-                if package_dir.exists("DEBIAN", s):
+                if package_dir.exists(os.path.join("DEBIAN", s)):
                     have_package_scripts = True
                     if package not in new_package_scripts:
                         new_package_scripts[package] = package_scripts
-                    with package_dir.open_file("DEBIAN", s, mode="r") as f:
+                    with package_dir.open_file(
+                        os.path.join("DEBIAN", s), mode="r"
+                    ) as f:
                         data = f.read()
                     package_scripts[s] = data
 
