@@ -145,7 +145,6 @@ def md5sum_file(vdir, path):
 # Element implementation for the 'dpkg_deploy' kind.
 class DpkgDeployElement(ScriptElement):
     BST_MIN_VERSION = "2.0"
-    BST_VIRTUAL_DIRECTORY = True
 
     def configure(self, node):
         node.validate_keys(["build-commands"])
@@ -202,7 +201,7 @@ class DpkgDeployElement(ScriptElement):
         super().configure_sandbox(sandbox)
 
         # We do some work in this directory, and need it to be read-write
-        sandbox.mark_directory("/buildstream", artifact=False)
+        sandbox.mark_directory("/buildstream")
 
     def stage(self, sandbox):
         super().stage(sandbox)
@@ -242,8 +241,10 @@ class DpkgDeployElement(ScriptElement):
 
             package_files = self.__input.compute_manifest(include=[package])
             vdir = sandbox.get_virtual_directory()
-            src = vdir.descend(*self.get_variable("build-root").split(os.sep))
-            dst = src.descend(package, create=True)
+            src = vdir.open_directory(
+                self.get_variable("build-root").lstrip(os.sep)
+            )
+            dst = src.open_directory(package, create=True)
 
             # link only the files for this package into it's respective package directory
             def package_filter(filename, package_files=package_files):
@@ -253,7 +254,7 @@ class DpkgDeployElement(ScriptElement):
 
             # Create this dir. If it already exists,
             # something unexpected has happened.
-            debiandir = dst.descend("DEBIAN", create=True)
+            debiandir = dst.open_directory("DEBIAN", create=True)
 
             # Recreate the DEBIAN files.
             # control is extracted verbatim, and is mandatory.
