@@ -79,7 +79,7 @@ class FastbootExt4ImageElement(ScriptElement):
         super().configure_sandbox(sandbox)
 
         # We do some work in this directory, and need it to be read-write
-        sandbox.mark_directory("/buildstream", artifact=False)
+        sandbox.mark_directory("/buildstream")
 
 
 # Plugin entry point
