@@ -208,7 +208,6 @@ creating intermediate layers that do not need to be exported.
 
 """
 
-import stat
 import os
 import tempfile
 import tarfile
@@ -219,7 +218,7 @@ import codecs
 import shutil
 from contextlib import contextmanager, ExitStack
 
-from buildstream import Element, ElementError
+from buildstream import Element, ElementError, FileType
 
 
 class blob:
@@ -275,7 +274,9 @@ class blob:
                     elif self.media_type.startswith(
                         "application/vnd.oci.image.layer.v1.tar"
                     ):
-                        blobdir = self.root.descend(h.hexdigest(), create=True)
+                        blobdir = self.root.open_directory(
+                            h.hexdigest(), create=True
+                        )
                         self.path = [h.hexdigest(), "layer.tar"]
                         with blobdir.open_file("VERSION", mode="w") as f:
                             f.write("1.0")
@@ -291,7 +292,7 @@ class blob:
                         )
                     else:
                         assert False
-            self.root.descend(*self.path[:-1], create=True)
+            self.root.open_directory(*self.path[:-1], create=True)
             self.root.rename([tempname], self.path)
         except Exception:
             if self.root.exists(tempname):
@@ -301,7 +302,6 @@ class blob:
 
 class OciElement(Element):
     BST_MIN_VERSION = "2.0"
-    BST_VIRTUAL_DIRECTORY = True
 
     def configure(self, node):
         node.validate_keys(["mode", "gzip", "images", "annotations"])
@@ -500,7 +500,9 @@ class OciElement(Element):
         if "layer" in image:
             if root.exists("parent_checkout"):
                 root.remove("parent_checkout", recursive=True)
-            parent_checkout = root.descend("parent_checkout", create=True)
+            parent_checkout = root.open_directory(
+                "parent_checkout", create=True
+            )
 
         layer_descs = []
         layer_files = []
@@ -526,7 +528,7 @@ class OciElement(Element):
         if "parent" in image:
             if root.exists("parent"):
                 root.remove("parent", recursive=True)
-            parent = root.descend("parent", create=True)
+            parent = root.open_directory("parent", create=True)
             parent_dep = self.search(image["parent"]["element"])
             if not parent_dep:
                 raise ElementError(
@@ -735,7 +737,7 @@ class OciElement(Element):
                                     parent_checkout.remove(
                                         *dirname.split("/"), recursive=True
                                     )
-                                    parent_checkout.descend(
+                                    parent_checkout.open_directory(
                                         *dirname.split("/"), create=True
                                     )
                                 elif basename.startswith(".wh."):
@@ -759,7 +761,7 @@ class OciElement(Element):
                 dep = self.search(name)
                 dep.stage_dependency_artifacts(sandbox, path="layer")
 
-            layer = root.descend("layer")
+            layer = root.open_directory("layer")
             with self.timed_activity("Transforming into layer"):
 
                 def create_whiteouts(parentdir, layerdir):
@@ -770,7 +772,8 @@ class OciElement(Element):
                         elif parentdir.isdir(f) and layerdir.isdir(f):
                             # Recurse into subdirectory
                             create_whiteouts(
-                                parentdir.descend(f), layerdir.descend(f)
+                                parentdir.open_directory(f),
+                                layerdir.open_directory(f),
                             )
 
                 create_whiteouts(parent_checkout, layer)
@@ -784,18 +787,16 @@ class OciElement(Element):
                             elif parentdir.isdir(f) and layerdir.isdir(f):
                                 # Recurse into subdirectory
                                 remove_duplicates(
-                                    parentdir.descend(f), layerdir.descend(f)
+                                    parentdir.open_directory(f),
+                                    layerdir.open_directory(f),
                                 )
                             else:
                                 old_st = parentdir.stat(f)
                                 new_st = layerdir.stat(f)
-                                if old_st.st_mode != new_st.st_mode:
+                                if old_st != new_st:
                                     continue
-                                if int(old_st.st_mtime) != int(
-                                    new_st.st_mtime
-                                ):
-                                    continue
-                                if stat.S_ISLNK(old_st.st_mode):
+
+                                if old_st.file_type == FileType.SYMLINK:
                                     if parentdir.readlink(
                                         f
                                     ) == layerdir.readlink(f):
@@ -916,7 +917,7 @@ class OciElement(Element):
 
     def assemble(self, sandbox):
         root = sandbox.get_virtual_directory()
-        output = root.descend("output", create=True)
+        output = root.open_directory("output", create=True)
 
         manifests = []
         legacy_repositories = {}
