@@ -33,7 +33,7 @@ See `built-in functionality documentation
 details on common configuration options for build elements.
 """
 
-from buildstream import BuildElement, SandboxFlags
+from buildstream import BuildElement
 
 
 # Element implementation for the 'pip' kind.
@@ -41,17 +41,6 @@ class PipElement(BuildElement):
 
     BST_MIN_VERSION = "2.0"
 
-    # Supports virtual directories (required for remote execution)
-    BST_VIRTUAL_DIRECTORY = True
-
-    # Enable command batching across prepare() and assemble()
-    def configure_sandbox(self, sandbox):
-        super().configure_sandbox(sandbox)
-        self.batch_prepare_assemble(
-            SandboxFlags.ROOT_READ_ONLY,
-            collect=self.get_variable("install-root"),
-        )
-
 
 # Plugin entry point
 def setup():
