@@ -83,7 +83,7 @@ class X86ImageElement(ScriptElement):
         super().configure_sandbox(sandbox)
 
         # We do some work in this directory, and need it to be read-write
-        sandbox.mark_directory("/buildstream", artifact=False)
+        sandbox.mark_directory("/buildstream")
 
 
 # Plugin entry point
