@@ -380,7 +380,7 @@ class GitTagMirror(SourceFetcher):
                 fail="Failed to retrieve list of remotes in {}".format(mirror),
                 cwd=mirror,
             )
-            if remote_name not in remotes:
+            if remote_name not in remotes.splitlines():
                 self.source.call(
                     [self.source.host_git, "remote", "add", remote_name, url],
                     fail="Failed to add remote {} with url {}".format(
@@ -491,13 +491,7 @@ class GitTagMirror(SourceFetcher):
                         tracking
                     )
                 )
-                _, output = self.source.check_output(
-                    [self.source.host_git, "rev-parse", tracking],
-                    fail="Unable to find commit for specified branch name '{}'".format(
-                        tracking
-                    ),
-                    cwd=self.mirror,
-                )
+                return None, None
             tracking = output.rstrip("\n")
 
         else:
@@ -837,6 +831,7 @@ class GitTagSource(AbstractGitTagSource):
             "match",
             "exclude",
             "checkout-submodules",
+            "submodules",
         ]
 
     def extra_configure(self, node):
@@ -969,9 +964,11 @@ class GitTagSource(AbstractGitTagSource):
                 ]
             )
 
+            candidates.pop(None, None)
+
             # Find latest candidate ref from all branches
             # Update self.mirror.ref, node.ref
-            ret = max(candidates, key=candidates.get)
+            ret = max(candidates, key=candidates.get, default=None)
 
         return ret
 
