@@ -4,7 +4,7 @@
 import subprocess
 import pytest
 
-from buildstream.testing import Repo
+from buildstream._testing import Repo
 from buildstream import utils, ProgramNotFoundError
 
 try:
